import{i as t}from"./client.74245462.js";function o(t){const o=t-1;return o*o*o+1}function r(r,n,e){const a=getComputedStyle(r),i="none"===a.transform?"":a.transform,s=n.from.width/r.clientWidth,f=n.from.height/r.clientHeight,m=(n.from.left-n.to.left)/s,l=(n.from.top-n.to.top)/f,c=Math.sqrt(m*m+l*l),{delay:d=0,duration:h=(t=>120*Math.sqrt(t)),easing:p=o}=e;return{delay:d,duration:t(h)?h(c):h,easing:p,css:(t,o)=>`transform: ${i} translate(${o*m}px, ${o*l}px);`}}export{r as f};
